Learn R Programming

weyl (version 0.0-8)

dot-class: Class “dot”

Description

The dot object is defined so that idiom like .[x,y] returns the commutator, that is, xy-yx.

The dot object is generated by running script inst/dot.Rmd, which includes some further discussion and technical documentation, and creates file dot.rda which resides in the data/ directory.

The borcherds vignette discusses this in a more general context.

Usage

# S4 method for dot,missing,missing
[(x, i, j, drop)
# S4 method for dot,ANY,missing
[(x, i, j, drop)
# S4 method for dot,missing,ANY
[(x, i, j, drop)
# S4 method for dot,matrix,matrix
[(x, i, j, drop)
# S4 method for dot,ANY,ANY
[(x, i, j, drop)
# S4 method for dot,function,function
[(x, i, j, drop)

Value

Always returns an object of the same class as xy.

Arguments

x

An object of class dot (typically the pre-built object “.”)

i, j

Elements to commute

drop

Logical; passed to drop() in the default method

Author

Robin K. S. Hankin

Examples

Run this code
x <- rweyl(n=1,d=2)
y <- rweyl(n=1,d=2)
z <- rweyl(n=1,d=2)

.[x,.[y,z]] + .[y,.[z,x]] + .[z,.[x,y]]  # Jacobi identity


Run the code above in your browser using DataLab