drop: Drop redundant information

dropR Documentation

Drop redundant information

Description

Coerce constant weyl objects to numeric

Usage

drop(x)

Arguments

x

Weyl object

Details

If its argument is a constant weyl object, coerce to numeric.

Value

Returns either a length-one numeric vector or its argument, a weyl object

Note

Many functions in the package take drop as an argument which, if TRUE, means that the function returns a dropped value.

Author(s)

Robin K. S. Hankin

Examples

a <- rweyl() + 67
drop(a)

drop(idweyl(9))

drop(constant(a, drop=FALSE))

weyl documentation built on July 14, 2026, 1:07 a.m.