| rweyl | R Documentation |
Creates random weyl objects: quick-and-dirty examples of Weyl algebra elements
rweyl(nterms = 3, vals = seq_len(nterms), dim = 3, powers = 0:2)
rweyll(nterms = 15, vals = seq_len(nterms), dim = 4, powers = 0:5)
rweylll(nterms = 50, vals = seq_len(nterms), dim = 8, powers = 0:7)
nterms |
Number of terms in output |
vals |
Values of coefficients |
dim |
Dimension of weyl object |
powers |
Set from which to sample the entries of the index matrix |
Function rweyl() creates a smallish random Weyl object;
rweyll() and rweylll() create successively more
complicated objects.
These functions use spray::rspray(), so the note there about
repeated rows in the index matrix resulting in fewer than nterms
terms applies.
Function rweyl1() returns a one-dimensional Weyl object.
Returns a weyl object
Robin K. S. Hankin
rweyl()
rweyll()
rweyl(d=7)
options(polyform = TRUE)
rweyl1()
options(polyform = FALSE) # restore default
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.