spray: Create spray objects

sprayR Documentation

Create spray objects

Description

Function spray() creates a sparse array; function weyl() coerces a spray object to a Weyl object.

Usage

spray(M, x, addrepeats=FALSE)

Arguments

M

An integer-valued matrix, the index of the weyl object

x

Numeric vector of coefficients

addrepeats

Boolean, specifying whether repeated rows are to be added

Details

The function is discussed and motivated in the spray package.

Value

Return a weyl or a Boolean

Author(s)

Robin K. S. Hankin

Examples


(W <- spray(matrix(1:36,6,6), 1:6))
weyl(W)

as.weyl(15, d=3)

weyl documentation built on July 14, 2026, 1:07 a.m.