Note that a similar system for multivariate Weyl algebras is not
desirable. We might want to consider the Weyl algebra generated by
\(\left\lbrace
x,y,z,\partial_x,\partial_y,\partial_z\right\rbrace\)
and correspondingly define R variables x,y,z,dx,dy,dz. But
then variable x is ambiguous: is it a member of the first Weyl
algebra or the third?