zero: The zero operator

zeroR Documentation

The zero operator

Description

The zero operator maps any function to the zero function (which maps anything to zero). To test for something being zero, use spray::is.zero(); package idiom would be is.zero().

Function zero() takes a single argument which is interpreted as the dimension of the result. So zero(dim(a)) returns a*0 (but is faster).

Usage

zero(d)

Arguments

d

Integer specifying dimensionality of the weyl object (twice the spray arity)

Value

A weyl object corresponding to the zero operator (or a Boolean for is.zero())

Examples

(a <- rweyl(d=5))
is.zero(a)
is.zero(a-a)
is.zero(a*0)

a == a + zero(dim(a))

zero(8)


weyl documentation built on July 14, 2026, 1:07 a.m.