| dot-class | R Documentation |
The dot object is defined so that idiom like .[x,y] returns
the commutator, that is, xy-yx.
The dot object is generated by running script inst/dot.Rmd,
which includes some further discussion and technical documentation,
and creates file dot.rda which resides in the data/
directory.
The borcherds vignette discusses this in a more general
context.
## S4 method for signature 'dot,missing,missing'
x[i, j, drop]
## S4 method for signature 'dot,ANY,missing'
x[i, j, drop]
## S4 method for signature 'dot,missing,ANY'
x[i, j, drop]
## S4 method for signature 'dot,matrix,matrix'
x[i, j, drop]
## S4 method for signature 'dot,ANY,ANY'
x[i, j, drop]
## S4 method for signature 'dot,function,function'
x[i, j, drop]
x |
An object of class |
i, j |
Elements to commute |
drop |
Logical; passed to |
Always returns an object of the same class as xy.
Robin K. S. Hankin
x <- rweyl(n=1,d=2)
y <- rweyl(n=1,d=2)
z <- rweyl(n=1,d=2)
.[x,.[y,z]] + .[y,.[z,x]] + .[z,.[x,y]] # Jacobi identity
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.