The dot object is defined so that idiom like .[x,y] returns
the commutator, that is, xy-yx.
The dot object is generated by running script inst/dot.Rmd,
which includes some further discussion and technical documentation,
and creates file dot.rda which resides in the data/
directory.
The borcherds vignette discusses this in a more general
context.
Usage
# S4 method for dot,missing,missing
[(x, i, j, drop)
# S4 method for dot,ANY,missing
[(x, i, j, drop)
# S4 method for dot,missing,ANY
[(x, i, j, drop)
# S4 method for dot,matrix,matrix
[(x, i, j, drop)
# S4 method for dot,ANY,ANY
[(x, i, j, drop)
# S4 method for dot,function,function
[(x, i, j, drop)
Value
Always returns an object of the same class as xy.
Arguments
x
An object of class dot (typically the
pre-built object “.”)