| zero | R Documentation |
The zero operator maps any function to the zero function (which maps
anything to zero). To test for something being zero, use
spray::is.zero(); package idiom would be is.zero().
Function zero() takes a single argument which is interpreted as
the dimension of the result. So zero(dim(a)) returns
a*0 (but is faster).
zero(d)
d |
Integer specifying dimensionality of the weyl object (twice the spray arity) |
A weyl object corresponding to the zero operator (or a Boolean
for is.zero())
(a <- rweyl(d=5))
is.zero(a)
is.zero(a-a)
is.zero(a*0)
a == a + zero(dim(a))
zero(8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.